@@ -339,10 +339,8 @@ gsd_timezone_monitor_finalize (GObject *obj)
                 g_clear_object (&priv->cancellable);
         }
 
-        if (priv->geoclue_client) {
+        if (priv->geoclue_client)
                 gclue_client_call_stop (priv->geoclue_client, NULL, NULL, NULL);
-                g_clear_object (&priv->geoclue_client);
-        }
 
         g_clear_object (&priv->dtm);
         g_clear_object (&priv->geoclue_simple);
